https://github.com/python/cpython/commit/5156e8fb0d846cfba2791ce4c134d1034d609b50
commit: 5156e8fb0d846cfba2791ce4c134d1034d609b50
branch: 3.15
author: Miss Islington (bot) <[email protected]>
committer: StanFromIreland <[email protected]>
date: 2026-06-13T14:00:54+01:00
summary:

[3.15] gh-77328: Update `base64` module RFC references to RFC 4648 (GH-151275) 
(#151438)

(cherry picked from commit e9339876883f96af2e406a92a05be647b7fbe5d5)

Co-authored-by: Stan Ulbrych <[email protected]>

files:
M Lib/base64.py

diff --git a/Lib/base64.py b/Lib/base64.py
index 4a0e9d446edb0b..fa562f74a81034 100644
--- a/Lib/base64.py
+++ b/Lib/base64.py
@@ -1,4 +1,4 @@
-"""Base16, Base32, Base64 (RFC 3548), Base85 and Ascii85 data encodings"""
+"""Base16, Base32, Base64 (RFC 4648), Base85 and Ascii85 data encodings"""
 
 # Modified 04-Oct-1995 by Jack Jansen to use binascii module
 # Modified 30-Dec-2003 by Barry Warsaw to add full RFC 3548 support
@@ -219,7 +219,7 @@ def urlsafe_b64decode(s, *, padded=False):
 characters present in the input.
 '''
 _B32_DECODE_MAP01_DOCSTRING = '''
-RFC 3548 allows for optional mapping of the digit 0 (zero) to the
+RFC 4648 allows for optional mapping of the digit 0 (zero) to the
 letter O (oh), and for optional mapping of the digit 1 (one) to
 either the letter I (eye) or letter L (el).  The optional argument
 map01 when not None, specifies which letter the digit 1 should be
@@ -266,7 +266,7 @@ def b32hexdecode(s, casefold=False, *, padded=True, 
ignorechars=b'',
                                                     extra_args='')
 
 
 # RFC 3548, Base 16 Alphabet specifies uppercase, but hexlify() returns
 # lowercase.  The RFC also recommends against accepting input case
 # insensitively.
 def b16encode(s, *, wrapcol=0):
@@ -266,7 +266,7 @@ def b32hexdecode(s, casefold=False, *, padded=True, 
 
 
-# RFC 3548, Base 16 Alphabet specifies uppercase, but hexlify() returns
+# RFC 4648, Base 16 Alphabet specifies uppercase, but hexlify() returns
 # lowercase.  The RFC also recommends against accepting input case
 # insensitively.

_______________________________________________
Python-checkins mailing list -- [email protected]
To unsubscribe send an email to [email protected]
https://mail.python.org/mailman3//lists/python-checkins.python.org
Member address: [email protected]

Reply via email to